aboutsummaryrefslogtreecommitdiff
path: root/qolab/math/spectral_utils.py
diff options
context:
space:
mode:
Diffstat (limited to 'qolab/math/spectral_utils.py')
-rw-r--r--qolab/math/spectral_utils.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/qolab/math/spectral_utils.py b/qolab/math/spectral_utils.py
index 150078c..d22574c 100644
--- a/qolab/math/spectral_utils.py
+++ b/qolab/math/spectral_utils.py
@@ -3,7 +3,7 @@ from scipy.fft import fft, rfft, irfft, rfftfreq
def spectrum(t, y):
"""
Spectrum of real value signal with stripped away zero frequency component.
Preserves amplitude of a coherent signal (Asin(f*t)) independent of sampling
rate and time interval.
"""
@@ -17,7 +17,7 @@ def spectrum(t, y):
def noise_density_spectrum(t,y):
"""
- Calculates noise amplitude spectral density (ASD), the end results has unitis of y/sqrt(Hz)
+ Calculate noise amplitude spectral density (ASD), the end results has unitis of y/sqrt(Hz)
i.e. it does sqrt(PSD) where PSD is powerd spectrum density.
Preserves the density independent of sampling rate and time interval.
"""
@@ -27,7 +27,7 @@ def noise_density_spectrum(t,y):
def noise_spectrum_smooth(fr, Ampl, Nbins=100):
"""
- Smooth spectrum, especially at high frequency end.
+ Smooth amplitude spectrum, especially at high frequency end.
Could be thought as logarithmic spacing running average.
Since we assume the spectrum of the nose, we do power average (rmsq on amplitudes)
Assumes that set of frequencies is positive and equidistant set.
@@ -3,7 +3,7 @@ from scipy.fft import fft, rfft, irfft, rfftfreq
def spectrum(t, y):
"""
- Spectrum of real value signal with stripped away zero frequency component.
+ Calculate spectrum of real value signal with stripped away zero frequency component.
Preserves amplitude of a coherent signal (Asin(f*t)) independent of sampling
rate and time interval.